@@ -3,27 +3,27 @@
                              -------------------
     begin                : mar ago 27 2002
     copyright            : (C) 2002 by Jaime Robles
-    email                : jaime@robles.nu
+    email                : jaime@robles.es
  ***************************************************************************/
 /******************************************************************************
  *                                                                            *
  *   This program is free software; you can redistribute it and/or modify     *
-*  it under the terms of the GNU General Public License as published by     *
-*  the Free Software Foundation; either version 2 of the License, or        *
-*  (at your option) any later version.                                      *
+* it under the terms of the GNU General Public License as published by     *
+* the Free Software Foundation; either version 2 of the License, or        *
+* (at your option) any later version.                                      *
  *                                                                            *
-*  This program is distributed in the hope that it will be useful,          *
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
-*  GNU General Public License for more details.                             *
+* This program is distributed in the hope that it will be useful,          *
+* but WITHOUT ANY WARRANTY; without even the implied warranty of           *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.See the            *
+* GNU General Public License for more details.                             *
  *                                                                            *
-*  You should have received a copy of the GNU General Public License        *
-*  along with this program; if not, write to the Free Software              *
-*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
+* You should have received a copy of the GNU General Public License        *
+* along with this program; if not, write to the Free Software              *
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA02111-1307USA*
  *****************************************************************************/
 
-#include <klocale.h>
-//#include <ostream.h>
+//#include <klocale.h>
+
 #include "awards.h"
 Awards::Awards(){
 	listOfAwards.clear();
