@@ -3,7 +3,7 @@
                              -------------------
     begin                : mar ago 27 2002
     copyright            : (C) 2002 by Jaime Robles
-    email                : jaime@robles.nu
+    email                : jaime@robles.es
  ***************************************************************************/
 /******************************************************************************
  *                                                                            *
