@@ -25,15 +25,15 @@
 
 #ifndef GLOBAL_DATA
 #define GLOBAL_DATA
-const int ENTITIES = 341;
+const int ENTITIES = 400;
 const int ZONES = 40+1;
-const int BANDS = 17;
-const int MODES = 30;
+const int BANDS = 28;
+const int MODES = 59;
 #endif
  
 #ifndef AWARDWAZ_H
 #define AWARDWAZ_H
-#include <klocale.h>
+//#include <klocale.h>
 #include "adif.h"
 
 
