@@ -8,7 +8,7 @@
 
 /******************************************************************************
  *                                                                            *
- *   This program is free software; you can redistribute it and/or modify     *
+ *   This program is free software; you can redistribute and/or modify     *
 *  it under the terms of the GNU General Public License as published by     *
 *  the Free Software Foundation; either version 2 of the License, or        *
 *  (at your option) any later version.                                      *
@@ -26,59 +26,50 @@
 #ifndef KLOG_H
 #define KLOG_H
 
-#ifdef HAVE_CONFIG_H
+#ifndef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include <kapp.h>
+
 #include <qaction.h>
-#include <qapplication.h>
+//#include <qapplication.h>
 #include <qwidget.h>
-//#include <qthread.h>
-#include <klineedit.h>
-#include <kcombobox.h>
 #include "klogui.h"
+
 #include <qlistview.h>
-#include <klistview.h>
 #include <qfile.h>
 #include <qdatetime.h>
 #include <qdatetimeedit.h>
 #include <qspinbox.h>
-#include <ktextedit.h>
+#include <qtextedit.h>
 #include <qstring.h>
 #include <qlabel.h>
 #include <qpoint.h>
 #include <qlcdnumber.h>
-#include <kglobal.h>
-//#include <klocale.h>
-#include <kpushbutton.h>
+//#include <kglobal.h> // for filePrint (the date format)
+#include <klocale.h>
+//#include <kpushbutton.h>
 #include <qcheckbox.h>
 #include <qmessagebox.h>
 #include <qfiledialog.h>
 #include <qstatusbar.h>
 #include <qcolor.h>
-//#include <qcolorgroup.h> // for cluster
 #include <qdialog.h>
 #include <qinputdialog.h>
-#include <knuminput.h>
-#include <kled.h>
-#include <kaboutapplication.h>
-#include <kaboutdata.h>
-#include <kpopupmenu.h>
 #include <qtimer.h>
 // The next two are for the cluster box
 #include <qsocket.h>
 #include <qurl.h>
 #include <qtextstream.h>
 // The next two are for printing
-#include <kprinter.h>
+#include <qprinter.h>
 #include <qpainter.h>
 #include <qprogressdialog.h>
 #include <qsplashscreen.h>
 #include <qpaintdevicemetrics.h>
-#include <kbugreport.h>
 #include <qtabwidget.h>
 #include <qstringlist.h>
-//#include <iostream.h>
+
 #include "awarddxcc.h"
 #include "awardwaz.h"  
 #include "qso.h"
@@ -94,9 +85,11 @@
 #include "awards.h"
 #include "award.h"
 #include "reference.h"
+
 //#include "klogtip.h"
 
 //#include <Qt3Support>
+//#include <iostream.h>
 //#include "ostream.h"
 
 // BANDS 9 {10/12/15/17/20/30/40/80/160}
@@ -124,6 +117,7 @@ class Klog : public klogui{
 
 	World world;
 //    Entity entity;
+	WorkedCalls workedCall;// worked and it is posible to reuse the data.
 
 	typedef QValueList<Qso> LogBook;
 
@@ -214,13 +208,15 @@ class Klog : public klogui{
     void slotBugReport();
     void slotModeChanged (int i);
     void slotBandChanged ();
+    void fillDXCCList();	// Fill the KLog tab
 
   private:
-
+	
 	Qso qso;
-	Qso previousQso;       // This and workedCall is to check if a call has been previously
-	WorkedCalls workedCall;// worked and it is posible to reuse the data.
+//	Qso previousQso;       // This and workedCall is to check if a call has been previously
+
 	bool completeWithPrevious;	// Configuration parameter
+	bool completedWithPrevious;
 	bool requireMandatory;		// Configuration parameter (requires all the mandatory data for all the QSO) (QRZ, date, time, band, mode, RST (TX&RX))
 	QString tempLogFile;	// Temp log to save automatically
 
@@ -259,9 +255,9 @@ class Klog : public klogui{
 	QString getThisQSODXLocator ();
 	int needToWorkFromCluster(const QString &tqrz, const int tband); // 0 confirmed, 1 worked, 2 new one, -1 error
 //    QColor stateColor(const QString &tqrz, const int tband);    
-    void showAwardsNumbers(); // Shows how many worked, confirmed, ...
-    void clearAwards();
-    void showDistancesAndBeam(const int dist, const int beam); // Shows distance and beam
+	void showAwardsNumbers(); // Shows how many worked, confirmed, ...
+	void clearAwards();
+	void showDistancesAndBeam(const int dist, const int beam); // Shows distance and beam
 
 // Worked before
 	void completeAllQSOsFromLog();
@@ -269,11 +265,12 @@ class Klog : public klogui{
 	void fillEntityBandState(const int enti);
 	void sortLog(); //To order by date the log and produce OLog
 	void showIfPreviouslyWorked(); // Uses previousQso and workedCall
-	void addToPreviouslyWorked(); // Uses previousQso and workedCall    
-	void completeThePreviouslyWorked();
+	//void addToPreviouslyWorked(const QString &qrz); // Uses previousQso and workedCall    
+	void slotcompleteThePreviouslyWorked();
 	void getAllTheCallsFromLog();// To be run once after the log is read from the disk.
 	
-	QString getNumberString(const int intNumber); //Receivs a number a returns a string of a fixed length
+	QString getNumberString(const int intNumber); //Receives a number a returns a string of a fixed length
+	QString getShortNumberString(const int intNumber); //Same that previous but with 3 characters
 	int getEntityFromCall(); // Just read the call from the QRZ box and returns the entity number
 
 	void prepareAwardComboBox(const int tenti);
@@ -299,9 +296,9 @@ class Klog : public klogui{
 	QString logFileNameToOpen;
 	QString logFileNameToSave;
 	QString aux;
-    QString operatorStringAux;
-    QString textStringAux;
-    QString KLogVersion;
+	QString operatorStringAux;
+	QString textStringAux;
+	QString KLogVersion;
 	QString dateString;
 	QString timeString;
 	QString datesString;
@@ -311,26 +308,27 @@ class Klog : public klogui{
 	QString theData;
  
 
-    KPrinter printer;
+	QPrinter printer;
 //    QPainter p;
 
-QColorGroup colorGroup; // For cluster
-    QPainter clusterPainter; // For cluster
-QColor confirmedColor;
-QColor workedColor;
-QColor neededColor;
-QColor defaultColor;
-QColor dxSpotColor;
-QColor blackColor;
-QColor colorInUse;  // Till now only in use in Klog::slotSearchButton()
-int number;  // QSO number
-int confirmed; //confirmed QSOs
-int rstrx;  // RST received from the other peer
-int rsttx;  // RST you pass to the other peer
-int tTxValue;
-int tRxValue;
-int sTxValue;
-int sRxValue;
+	QColorGroup colorGroup; // For cluster
+	QPainter clusterPainter; // For cluster
+	QColor confirmedColor;
+	QColor workedColor;
+	QColor neededColor;
+	QColor newOneColor;
+	QColor defaultColor;
+	QColor dxSpotColor;
+	QColor blackColor;
+	QColor colorInUse;  // Till now only in use in Klog::slotSearchButton()
+	int number;  // QSO number
+	int confirmed; //confirmed QSOs
+	int rstrx;  // RST received from the other peer
+	int rsttx;  // RST you pass to the other peer
+	int tTxValue;
+	int tRxValue;
+	int sTxValue;
+	int sRxValue;
 
 
 	int band;   // Band used in the QSO
@@ -361,43 +359,45 @@ int sRxValue;
 //bool justOneTime; //  For slotQslRec to avoid twice confirmed--
 	bool wasConfirmed; // For the same purporse as above.
 	bool openLastByDefault;
-QString mode;
-QString qrz;  // Just used in the searching functions
-QString iota;
-QString localAward;	// A String as the iota to temporaly save the localAward (if any)
-QDateTime dateTime;
-QDateTime dateTimeContinuous;
-QDate qslSen;
-QDate qslRec;
-//QDate date;
-//QTime time;
-QString comment;
-QString dateTimeString;
-//Preferences setupDialog;
+	QString mode;
+	QString qrz;  // Just used in the searching functions
+	QString iota;
+	QString localAward;	// A String as the iota to temporaly save the localAward (if any)
+	QDateTime dateTime;
+	QDateTime dateTimeContinuous;
+	QDate qslSen;
+	QDate qslRec;
+	//QDate date;
+	//QTime time;
+	QString comment;
+	QString dateTimeString;
+	//Preferences setupDialog;
 
-QPixmap *editdeletePixMap;
-QPixmap *editdeleteOffPixMap;
-QPixmap *qslRecPixMap;
-QPixmap *qslRecOffPixMap;
-QPixmap *qslSenPixMap;
-QPixmap *qslSenOffPixMap;
+	QPixmap *editdeletePixMap;
+	QPixmap *editdeleteOffPixMap;
+	QPixmap *qslRecPixMap;
+	QPixmap *qslRecOffPixMap;
+	QPixmap *qslSenPixMap;
+	QPixmap *qslSenOffPixMap;
 // Cluster variables
-int neededWorkedConfirmed; // 0 needed, 1 worked, 2 confirmed, 3 default
-QSocket *socket;
-QLineEdit *inputText;
-QString dxClusterHost;
-QString dxClusterString;
-QString dxClusterDxCall;
-QString dxClusterShow;
+//	int neededWorkedConfirmed; // 0 needed, 1 worked, 2 confirmed, 3 default
+	QSocket *socket;
+	QLineEdit *inputText;
+	QString dxClusterHost;
+	QString dxClusterString;
+	QString dxClusterDxCall;
+//	QString dxClusterShow;
 //QString dxClustertmp;
-int dxClusterPort;
-int dxClusterCallLen;
-int dxClusterEnti;
-int dxClusterBand; // tmp variable
+	int dxClusterPort;
+	int dxClusterCallLen;
+	int dxClusterEnti;
+	int dxClusterBand; // tmp variable
 	bool dxClusterConnected;
 	bool dxClusterHFSpots;
 	bool dxClusterVHFSpots;
 	bool dxClusterWARCSpots;
+	bool dxClusterCWSpots;
+	bool dxClusterSSBSpots;
 	bool dxClusterWXANNounces;
 	bool dxClusterWCYANNounces;
 	bool dxClusterANNounces;
@@ -405,35 +405,34 @@ int dxClusterBand; // tmp variable
 //void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment );
 //  virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
 
-KBugReport  *bugReport;
-// 0 QRZ
-// 1 Date
-// 2 Time
-// 3 Band
-// 4 Mode
-// 5 RST tx
-// 6 RST rx
-bool haveAllMandatoryFields[6];
+//	KBugReport  *bugReport;
+	// 0 QRZ
+	// 1 Date
+	// 2 Time
+	// 3 Band
+	// 4 Mode
+	// 5 RST tx
+	// 6 RST rx
+	bool haveAllMandatoryFields[6];
 
-// hamlib support
-kloghamlib KlogHamlib;
-bool hamlib;
-bool hamlibReading;
-bool hamlibPossible;
-double hamlibFreq;
-int bauds;
-int rignameNumber;
-//int strength;
-int hamlibInterval;
-QString serialPort;
-QTimer *hamlibtimer;
+	// hamlib support
+	kloghamlib KlogHamlib;
+	bool hamlib;
+	bool hamlibPossible;
+	double hamlibFreq;
+	int bauds;
+	int rignameNumber;
+	//int strength;
+	int hamlibInterval;
+	QString serialPort;
+	QTimer *hamlibtimer;
 
 
 };
 
-class dxClusterSpotItem : public KListViewItem {
+class dxClusterSpotItem : public QListViewItem {
 public:
-dxClusterSpotItem( KListView *parent, const QString& spot, const QColor& color );
+dxClusterSpotItem( QListView *parent, const QString& spot, const QColor& color );
 ~dxClusterSpotItem();
 virtual void paintCell( QPainter *p, const QColorGroup &cg,
 int column, int width, int alignment );
@@ -447,9 +446,9 @@ protected:
 };
 
 
-class searchBoxItem : public KListViewItem {
+class searchBoxItem : public QListViewItem {
 public:
-searchBoxItem( KListView *parent, const QString& call, const QString& date, const QString& time, const QString& band, const QString& mode, const QString& RSTsent, const QString& RSTrec, const QString& numb, const QColor& color );
+searchBoxItem( QListView *parent, const QString& call, const QString& date, const QString& time, const QString& band, const QString& mode, const QString& RSTsent, const QString& RSTrec, const QString& numb, const QColor& color );
 ~searchBoxItem();
 virtual void paintCell( QPainter *p, const QColorGroup &cg,
         int column, int width, int alignment );
@@ -465,21 +464,21 @@ protected:
   QString RSTrec;
 };
 
-// class bandMapSpotItem : public KListViewItem {
-// // Items for the BandMap
-// public:
-// bandMapSpotItem( KListView *parent, const QString& freq, const QString& dx, const QString& from, const QColor& dxcolor );
-// ~bandMapSpotItem();
-// virtual void paintCell( QPainter *p, const QColorGroup &cg,
-//                             int column, int width, int alignment );
-// 
-// //Message *message() { return myMessage; }
-// 
-// protected:
-//   //  Message *myMessage;
-// 	QColor spotColor;
-// 	
-// 
-// };
+
+
+
+class dxccItem : public QListViewItem {
+public:
+dxccItem( QListView *parent, const QString& numb, const QString& ent, const QString& pref, const QString& m10, const QString& m12, const QString& m15, const QString& m17, const QString& m20, const QString& m30, const QString& m40, const QString& m80, const QString& m160, const QColor& color );
+
+~dxccItem();
+virtual void paintCell( QPainter *p, const QColorGroup &cg,int column, int width, int alignment );
+
+
+protected:
+  QColor qsoColor;
+
+};
+
 
 #endif
