@@ -3,7 +3,7 @@
                              -------------------
     begin                : jue ago 15 2002
     copyright            : (C) 2002 by Jaime Robles
-    email                : jaime@robles.nu
+    email                : jaime@robles.es
  ***************************************************************************/
 
 /******************************************************************************
@@ -38,7 +38,7 @@ class Qso{
 public:
   Qso();
   Qso(const QString& tqrz, int tnumb, QString& tmode);
-  Qso (const int tnumb, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower);
+  Qso (const int tnumb, const QString& tqrz, const int trstrx, const int trsttx, const QString& tmode, const QString& tband, const int tpower);
   // Next constructor is used to read log
   Qso (const int tnumb, const QDateTime tdateTime, const QString& tqrz, const int trstrx, const int trsttx, const QString& tband, const QString& tmode, const QString& tpower, const QString& tcomment);
   Qso (const int tnumb, const QDateTime& tdateTime, const QString& tqrz, const int trstrx, const int trsttx, int tband, const QString& tmode, const int tpower, const QDate& tqslSen,  const QDate& tqslRec, const QString& tcomment);  
@@ -69,11 +69,18 @@ public:
   int getRsttx() const;
 
   void setBand (const QString& tband);
-  QString getBand() const;  
+  QString getBand() const;
 
-  void setFreq (const QString& tfreq);
+  void setBand_RX (const QString& tband);
+  QString getBand_RX() const;
+
+
+  void setFreq (const QString& tfreq); // In MHz (14, 14.195, ...)
   QString getFreq() const;
 
+  void setFreq_RX (const QString& tfreq); // In MHz (14, 14.195, ...)
+  QString getFreq_RX() const;
+
   void setMode(const QString& tmode);
   QString getMode() const;  
 
@@ -83,11 +90,37 @@ public:
 	void setrxPower(const QString& tpower);
 	QString getrxPower() const;
 
-  void setQslSenDateOn(QDate tdate);
-    QDate getQslSenDate() const;
+	void setDXCC (int tnumb);	// ADIF DXCC Country code
+	int getDXCC() const;		// ADIF DXCC Country code
+
+	void setAge (int tnumb);	// Contacted operator age in years
+	int getAge() const;		// Contacted operator age in years
+
+	void setAnt_az (int tnumb);	//Antenna azimut in degrees
+	int getAnt_az() const;		//Antenna azimut in degrees
+	void setAnt_el (int tnumb);	//Antenna elevation in degrees
+	int getAnt_el() const;		//Antenna elevation in degrees
+
+
+	void setA_index (int tnumb); // geomagnetic A index at the time of the QSO
+	int getA_index() const;	// geomagnetic A index at the time of the QSO
+
+
+   void setQslSenDateOn(QDate tdate);
+   QDate getQslSenDate() const;
+
+  void seteQslSenDateOn(QDate tdate);
+  QDate geteQslSenDate() const;
+  void seteQslRecDateOn(QDate tdate);
+  QDate geteQslRecDate() const;
+
+   void seteQslSent(const QChar& eqslState); // eQSL_Sent Y, N, R, Q, I
+   QChar geteQslSent();
+   void seteQslRcvd(const QChar& eqslState); // eQSL_RCVD Y, N, R, I, V
+   QChar geteQslRcvd();
 
   void QslSent(const QChar& qslState);
-    QChar isQslSent();
+  QChar isQslSent();
 
   void setQslRecDateOn(QDate tdate);
   QDate getQslRecDate() const;
@@ -124,18 +157,44 @@ public:
   void setLocalAward(const QString &taward);
   QString getLocalAward() const;
 
-
   void setLocalAwardNumber(int taward); // Those two functions are just for awards reference
   int getLocalAwardNumber() const;      // management
 
   void setName(const QString &tname);
-  QString getName() const;  
+  QString getName() const; 
+
+  void setContinent(const QString &tcont);
+  QString getContinent() const; 
+
+  void setContactedOP(const QString &tqrz);
+  QString getContactedOP() const;
+
+  void setEQCall(const QString &tqrz); // the  contacted station's owner's callsign
+  QString getEQCall() const;
+
+  void setEmail(const QString &temail);
+  QString getEmail() const;
+
+  void setWeb(const QString &tweb);
+  QString getWeb() const;
+
+
+  void setCQz (int tnumb);
+  int getCQz() const;
+  void setITUz (int tnumb);
+  int getITUz() const;
+
+  void setDistance (int tnumb);
+  int getDistance() const;
 
   void setQth(const QString &tqth);
   QString getQth() const;
 
-  void setOperator(const QString &toperator); // Call used to work this QSO
-  QString getOperator() const;                // Call used to work this QSO
+  void setOperator(const QString &toperator); // Operator that works this QSO
+  QString getOperator() const;                // Operator that works this QSO
+
+  void setStationCallsign(const QString &toperator); // Call used to work this QSO
+  QString getStationCallsign() const;                // Call used to work this QSO
 
  void setPropMode(const QString &tprop_mode);
  QString getPropMode() const;
@@ -149,27 +208,43 @@ public:
 	int getStx() const;
 	void setStx_string(const QString &tstx);
 	QString getStx_string() const;
+	void setContestID(const QString &tcontestid); // Contest identifier
+	QString getContestID() const;                // Contest identifier
+
 /********************* CONTESTS ********************/
+
+   void setAnt_Path(const QChar& tantpath); // ANT_PATH  = G, O, S, L
+   QChar getAnt_Path();
+
+
   void clearQso();
 
 private:
 	QString	sAux;	//Auxiliar variable
   QString qrz;        // CALL
-  int numb;           // STX
+  int numb;           // 
   QDateTime dateTime; // QSO_DATE/TIME_ON YYYYMMDD - Time HHMM (0000-2359)
   int rstrx;          // RST_RCVD
   int rsttx;          // RST_SENT
   QString freq;       // Frecuency
+  QString freq_rx;       // Frecuency
   QString band;       // BAND
+  QString band_rx;       // BAND_RX
 
+	int dxcc;	// ADIF DXCC country code
   QString mode;       // MODE
   QString rx_power;   // RX_PWR
   QString power;      // TX_PWR
   QDate qslSen;       // QSLSDATE
   QDate qslRec;       // QSLRDATE
+  QDate eqsl_qslrdate;	//EQSL_QSLRDATE
+  QDate eqsl_qslsdate;	//EQSL_QSLSDATE
   QString comment;    // COMMENT
   QChar qslRecc;      // QSL_RCVD Y, N, R, I
   QChar qslSenc;      // QSL_SENT Y, N, R, I
+  QChar eQSL_qsl_rcvd; // eQSL_RCVD Y, N, R, I, V
+  QChar eQSL_qsl_sent; // eQSL_Sent Y, N, R, Q, I
+  QChar ant_path;	// G, O, S, L, N(null)
   QString qslVia;     // QSL_VIA (C) //Manager
   QString qslInfo;    // ADDRESS /QSLMSG
   QString manager;
@@ -179,16 +254,30 @@ private:
   QString iota;       // IOTA
   QString localAward;	// Each Entity may have a local award reference (TPEA, WAS, ...)
   int localAwardNumber; // Just a help for award references management but not saved into the log
-  QString callUsed;   // OPERATOR/Call used to work this QSO
+  QString station_callsign;   // Call used to work this QSO.
+  QString operatorc;   // OPERATOR/Call(only if not station_callsign is present) used to work this QSO
+  QString contacted_op; // the callsign of the individual operating the  contacted station
+  QString eq_call;	//The  contacted station's owner's callsign
   QString state;    // STATE
   QString name;       // NAME
+  QString cont;		// Contacted Continent
   QString qth;        // QTH
+  QString email;	// Contacted station's email
+  QString web;		// Contacted station's web
+  int age;		// Contacted operator age in years
+  int a_index;		// geomagnetic A index at the time of the QSO
+  int ant_az;	//Antenna azimut in degrees
+  int ant_el;	//Antena elevation
+  int cqz;
+  int ituz;
+  int distance;
   QString prop_mode;  // PROP_MODE QSO propagation mode
 /***************** CONTEST FIELDS *************************/
 	int srx;		//contest QSO received serial number
 	int stx;		//contest QSO transmitted serial number
 	QString srx_string; 	//contest QSO received information
 	QString stx_string; 	//contest QSO transmitted information
+	QString contest_id;	// Contest identifier
 /***************** CONTEST FIELDS *************************/
 	
 	// Checks that the data is not an ADIF field and replaces </> by a (/).
@@ -196,11 +285,9 @@ private:
 	QString checkLines(const QString& tword);
 
 
-	//int age;	//Contacted operator's age
-	//int ant_az;	//Antenna azimut in degrees
-	//int ant_el;	//Antena elevation
+	
 	//QString band_rx; // In split oprations the RX band
-	//Contest_id;	// QSO Contest indentifier
+	
 	//cqz;		// CQ Zone 
 	//ituz;		// ITU Zone
 	//QString freq_rx;
