@@ -66,6 +66,54 @@ void Setup::slotOkBtnClicked(){
 }
 
 
+void Setup::slotConfirmedColorPushButton(){
+//cout << "Setup::slotConfirmedColorPushButton " << endl;
+	colorGroup = setupui::confirmedPushButton->colorGroup();
+	setupui::confirmedPushButton->setPaletteBackgroundColor(giveColor(setupui::confirmedPushButton->paletteBackgroundColor()));
+}
+
+
+void Setup::slotWorkedColorPushButton(){
+//cout << "Setup::slotWorkedColorPushButton " << endl;
+	colorGroup = setupui::workedPushButton->colorGroup();
+	setupui::workedPushButton->setPaletteBackgroundColor(giveColor(setupui::workedPushButton->paletteBackgroundColor()));
+}
+
+void Setup::slotNeededColorPushButton(){
+//cout << "Setup::slotNeededColorPushButton " << endl;
+	colorGroup = setupui::neededPushButton->colorGroup();
+	setupui::neededPushButton->setPaletteBackgroundColor(giveColor(setupui::neededPushButton->paletteBackgroundColor()));
+}
+
+void Setup::slotNewOneColorPushButton(){
+//cout << "Setup::slotNeededColorPushButton " << endl;
+	colorGroup = setupui::newOnePushButton->colorGroup();
+	setupui::newOnePushButton->setPaletteBackgroundColor(giveColor(setupui::newOnePushButton->paletteBackgroundColor()));
+}
+
+
+void Setup::slotDefaultColorPushButton(){
+//cout << "Setup::slotDefaultColorPushButton " << endl;
+	colorGroup = setupui::defaultPushButton->colorGroup();
+	setupui::defaultPushButton->setPaletteBackgroundColor(giveColor(setupui::defaultPushButton->paletteBackgroundColor()));
+}
+QColor Setup::giveColor(QColor c){
+/* Receives the actual color, shows the user a color picker and returns the color
+that the user selects.
+*/
+//cout << "Setup::giveColor " << endl;
+	QColor colorb;
+	color = c;
+	colorb = color;
+	color = QColorDialog::getColor(color,this, "color dialog" );
+	if (color.isValid()){
+		return color;
+	}else{
+		return colorb;
+	}
+
+}
+
 void Setup::readConf(){
 	QFile file( "klogrc" );
 	if ( file.open( IO_ReadOnly ) ) {
@@ -228,6 +276,21 @@ void Setup::readConf(){
           }else if ((theData.upper() == "FALSE")){
             setupui::WARCcheckBox->setChecked(false);
           }
+
+       }else if (adifTab == "DXCLUSTERCWSPOTS"){
+          if (theData.upper() == "TRUE"){
+            setupui::CWcheckBox->setChecked(true);
+          }else if ((theData.upper() == "FALSE")){
+            setupui::CWcheckBox->setChecked(false);
+          }
+       }else if (adifTab == "DXCLUSTERSSBSPOTS"){
+          if (theData.upper() == "TRUE"){
+            setupui::SSBcheckBox->setChecked(true);
+          }else if ((theData.upper() == "FALSE")){
+            setupui::SSBcheckBox->setChecked(false);
+          }
+
+
       }else if (adifTab == "DXCLUSTERANNOUNCES"){
           if (theData.upper() == "TRUE"){
             setupui::ANNcheckBox->setChecked(true);
@@ -260,16 +323,24 @@ void Setup::readConf(){
           }
         }else if (adifTab == "CONFIRMEDCOLOR"){
           color.setNamedColor(theData.upper());
-          setupui::confirmedkColorCombo->setColor(color);
-        }else if (adifTab == "WORKEDCOLOR"){
+          //setupui::confirmedkColorCombo->setColor(color);
+	setupui::confirmedPushButton->setPaletteBackgroundColor(color);
+	}else if (adifTab == "WORKEDCOLOR"){
           color.setNamedColor(theData.upper());
-          setupui::workedkColorCombo->setColor(color);
+//          setupui::workedkColorCombo->setColor(color);
+setupui::workedPushButton->setPaletteBackgroundColor(color);
         }else if (adifTab == "NEEDEDCOLOR"){
           color.setNamedColor(theData.upper());
-          setupui::neededkColorCombo->setColor(color);
+//          setupui::neededkColorCombo->setColor(color);
+setupui::neededPushButton->setPaletteBackgroundColor(color);
+        }else if (adifTab == "NEWONECOLOR"){
+          color.setNamedColor(theData.upper());
+//          setupui::neededkColorCombo->setColor(color);
+setupui::newOnePushButton->setPaletteBackgroundColor(color);
         }else if (adifTab == "DEFAULTCOLOR"){
           color.setNamedColor(theData.upper());
-          setupui::defaultkColorCombo->setColor(color);
+//          setupui::defaultkColorCombo->setColor(color);
+setupui::defaultPushButton->setPaletteBackgroundColor(color);
         }else if (adifTab == "POWER"){
           setupui::powerkIntNumInput->setValue(theData.toInt());
         }else if (adifTab == "DEFAULTBAND"){
@@ -294,15 +365,16 @@ void Setup::readConf(){
           // 25-03-2004
           //////////////////////////////////////////////////////////////////////////////
           }else if (adifTab == "RIGNAME"){
-       comboBoxTrvList->setCurrentText(rigid2rigname[theData.toInt()]);
+		comboBoxTrvList->setCurrentText(rigid2rigname[theData.toInt()]);
           }else if (adifTab == "PORT"){
 //       comboBoxTrvPortList->setCurrentText(theData);
-       devicelineEdit->setText(theData);
+		devicelineEdit->setText(theData);
           }else if (adifTab == "BAUDS"){
        //comboBoxTrvSpeedList->setCurrentText(theData);
        		//speedlineEdit->setText(theData);
 //		cout << "Klog::readConf: " << QString::number(theData.toInt()) << endl;
-       		setupui::comboBoxTrvSpeedList->setCurrentItem(theData.toInt());
+
+		setupui::comboBoxTrvSpeedList->setCurrentItem(bauds2Num(theData));
        }
           //////////////////////////////////////////////////////////////////////////////
           // End of modifications
@@ -373,6 +445,20 @@ void Setup::writeConf(){
 			tmp="false";
 		}
 		stream << "dxclusterhfspots=" + tmp << endl;
+		if (setupui::CWcheckBox->isChecked()){
+			tmp="true";
+		}else{
+			tmp="false";
+		}
+		stream << "dxclustercwspots=" + tmp << endl;
+		if (setupui::SSBcheckBox->isChecked()){
+			tmp="true";
+		}else{
+			tmp="false";
+		}
+		stream << "dxclusterssbspots=" + tmp << endl;
+
+
 		if (setupui::completeWithPreviouscheckBox->isChecked()){
 			tmp="true";
 		}else{
@@ -396,7 +482,7 @@ void Setup::writeConf(){
 		}else{
 			tmp="false";
 		}
-		stream << "dxclusterwarcspots=" + tmp << endl;        
+		stream << "dxclusterwarcspots=" + tmp << endl;
 		if (setupui::ANNcheckBox->isChecked()){
 			tmp="true";
 		}else{
@@ -429,10 +515,18 @@ void Setup::writeConf(){
 		}
 		stream << "realTimeLog=" + tmp << endl;
 		// Color scheme...
-		stream << "ConfirmedColor=" + (setupui::confirmedkColorCombo->color()).name() << endl;
-		stream << "WorkedColor=" + (setupui::workedkColorCombo->color()).name() << endl;
-		stream << "NeededColor=" + (setupui::neededkColorCombo->color()).name() << endl;
-		stream << "DefaultColor=" + (setupui::defaultkColorCombo->color()).name() << endl;    
+
+//		stream << "ConfirmedColor=" + (setupui::confirmedkColorCombo->color()).name() << endl;
+		colorGroup = setupui::confirmedPushButton->colorGroup();
+		stream << "ConfirmedColor=" + (setupui::confirmedPushButton->paletteBackgroundColor()).name() << endl;
+		stream << "WorkedColor=" + (setupui::workedPushButton->paletteBackgroundColor()).name() << endl;
+// (setupui::workedkColorCombo->color()).name() << endl;
+		stream << "NeededColor=" + (setupui::neededPushButton->paletteBackgroundColor()).name() << endl;
+// (setupui::neededkColorCombo->color()).name() << endl;
+		stream << "NewOneColor=" + (setupui::newOnePushButton->paletteBackgroundColor()).name() << endl;
+// (setupui::neededkColorCombo->color()).name() << endl;
+		stream << "DefaultColor=" + (setupui::defaultPushButton->paletteBackgroundColor()).name() << endl;
+// (setupui::defaultkColorCombo->color()).name() << endl;    
 		stream << "Power=" + QString::number(setupui::powerkIntNumInput->value()) << endl;
 		if (setupui::lastFilecheckBox->isChecked() && (setupui::filenamekLineEdit->text() != "")){
 			tmp="true";
@@ -459,14 +553,10 @@ void Setup::writeConf(){
 			stream << "Award=" + (*itl)->text(3) << endl;
 		}
 
-
 		stream << "HamLib=" + tmp << endl;
 		stream << "RigName=" << rigname2rigid[comboBoxTrvList->currentText()] << endl;
-			stream << "Port=" << devicelineEdit->text() << endl;    
-  			// stream << "Port=" << comboBoxTrvPortList->currentText() << endl;
-			//stream << "Bauds=" << speedlineEdit->text() <<endl;    
-			//stream << "s=" << comboBoxTrvSpeedList->currentText() << endl;
-			 stream << "Bauds=" << QString::number(setupui::comboBoxTrvSpeedList->currentItem())<<endl;
+			stream << "Port=" << devicelineEdit->text() << endl;
+			stream << "Bauds=" << setupui::comboBoxTrvSpeedList->currentText()<<endl;
 			stream << "HamlibInterval=" << QString::number(setupui::hamlibIntervalspinBox->value()) << endl;
      ///////////////////////////////////////////////////////////////////////////////
     // Modifications by kike
@@ -476,7 +566,7 @@ void Setup::writeConf(){
     //////////////////////////////////////////////////////////////////////////////
     // End of modifications
     //////////////////////////////////////////////////////////////////////////////
-   
+
 		file.close();
 	}
   
@@ -521,7 +611,7 @@ void Setup::slotSearchAwardFilekPushButtonClicked(){
 
 
 void Setup::slotAddButtonClicked(){
-	//cout << "Setup::slotAddButtonClicked" << endl;
+//cout << "Setup::slotAddButtonClicked" << endl;
 	awardFileName = setupui::awardFilenamekLineEdit->text();
 	if (awardFileName.isEmpty()){
 		slotSearchAwardFilekPushButtonClicked();
@@ -748,15 +838,15 @@ void Setup::showMenuRightButton(int taward, const QPoint &p){
 // 25-03-2004
 //////////////////////////////////////////////////////////////////////////////
 int Setup::addRigToList(const struct rig_caps* caps, void* data){
-        QString name;
-  Setup* r = (Setup*)data;
-        name=caps->model_name;
-        if (name == "Dummy")
-                name = "None";
-  r->rigname2rigid[name] = caps->rig_model;
-  r->rigid2rigname[caps->rig_model] = name;
-        r->strings << name;
-  return -1; // not 0 --> we want all rigs
+	QString name;
+	Setup* r = (Setup*)data;
+	name=caps->model_name;
+	if (name == "Dummy")
+		name = "None";
+	r->rigname2rigid[name] = caps->rig_model;
+	r->rigid2rigname[caps->rig_model] = name;
+	r->strings << name;
+	return -1; // not 0 --> we want all rigs
 }
 
 void Setup::setRig()
@@ -776,4 +866,45 @@ void Setup::setRig()
 // End of modifications
 //////////////////////////////////////////////////////////////////////////////
 
+int Setup::bauds2Num(const QString& tbauds){
+	switch (tbauds.toInt()){
 
+		case 1200:
+			return 0;
+		break;
+
+		case 2400:
+			return 1;
+		break;
+
+		case 4800:
+			return 2;
+		break;
+
+		case 9600:
+			return 3;
+		break;
+
+		case 19200:
+			return 4;
+		break;
+
+		case 38400:
+			return 5;
+		break;
+
+		case 57600:
+			return 6;
+		break;
+
+		case 115200:
+			return 7;
+		break;
+
+		default: // 
+			return 2;
+		break; 
+	}
+
+
+}
