@@ -22,16 +22,19 @@
 *  along with this program; if not, write to the Free Software              *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
  *****************************************************************************/
-#include <klocale.h>
+//#include <klocale.h>
 //#include <kdebug.h>
-//#include <ostream.h>
+
+//#include "iostream"
 #include "world.h"
+
+using namespace std; 
  
 World::World(){
-    prefix = "NULL"; // It is just a fake prefix to start with
-     int cqzone = 0; 
-     int ituzone = 0;
-     QString finalPrefix;
+  prefix = "NULL"; // It is just a fake prefix to start with
+  int cqzone = 0; 
+  int ituzone = 0;
+  QString finalPrefix;
 
 
   created = false;
@@ -48,7 +51,7 @@ World::World(){
       file.setName( klogDir+"/cty.dat" );      
       //cout << "homeDirPath: " << QDir::homeDirPath() << endl;
       */
-}
+  }
 // I have no idea where cty.dat is!!!
 
   if ( file.open( IO_ReadOnly ) ) {
@@ -62,95 +65,138 @@ World::World(){
       QStringList fields = QStringList::split(SEPARATOR1, data );
       cqzone = fields[1].toInt();
       ituzone = fields[2].toInt();
-    entity.setNumb(number);
-    entity.setEntity( fields[0].latin1() );
-    entity.setPfx((fields[7].stripWhiteSpace()).latin1());
-    entity.setCqz(cqzone);
-    entity.setLon(fields[5].toDouble());
-    entity.setLat( fields[4].toDouble());
-    entity.setContinent( fields[3].latin1());
-    entity.setItuz(ituzone);
-    entity.setTimeZone( fields[6].toInt());
-    World::nmap[number] = entity;
+      entity.setNumb(number);
+      entity.setEntity( fields[0].latin1() );
+      if (           ((fields[7].stripWhiteSpace()).contains("*"))>0   ) {
+        entity.setPfx(((fields[7].stripWhiteSpace()).remove("*")).latin1());
+      }else{
+        entity.setPfx((fields[7].stripWhiteSpace()).latin1());
+      }
+      entity.setCqz(cqzone);
+      entity.setLon(fields[5].toDouble());
+      entity.setLat( fields[4].toDouble());
+      entity.setContinent( fields[3].latin1());
+      entity.setItuz(ituzone);
+      entity.setTimeZone( fields[6].toDouble());
+      World::map[entity.getPfx()] = entity;
+// cout << QString::number(entity.getNumb()) << " - " << entity.getEntity() << " - Pref: " << entity.getPfx() << endl;
+// cout << "CQz: " << QString::number(entity.getCqz()) << " - ITUz: " << QString::number(entity.getItuz()) << endl;
+// cout << "Continent: " << entity.getContinent() << " - TimeZone: " << QString::number(entity.getTimeZone()) << endl;
+// cout << "Lat: " << QString::number(entity.getLat()) << " - Lon: " << QString::number(entity.getLon()) << endl;
+// cout << "==========================================================================================" << endl << endl;
+
+      World::nmap[number] = entity;
       //I create another data stream to process all prefixes
       // and then split the line
       QString datab = stream.readLine();
-      datab.remove(0,4);  //removing the spaces at the begining of the lines
+      datab.stripWhiteSpace();
+
       QStringList prefs = QStringList::split(SEPARATOR2, datab );
+
       //While the line does not have a ";"
-      while( !(datab.contains(';') ) ){
-        ij = (datab.contains(','));
+      while( (datab.contains(";"))<1 ) {
+        ij = (datab.contains(","));
+	datab.remove(0,4);
         n = 0;
+        QStringList prefs = QStringList::split(SEPARATOR2, datab );
         while (n < ij){
-     cqzone = fields[1].toInt();
-     ituzone = fields[2].toInt();
-     finalPrefix = prefs[n];
+          cqzone = fields[1].toInt();
+          ituzone = fields[2].toInt();
 
-     // Here I have the prefix but also the (zone)[zone] when special zone is added 
-     // HERE IS NECESARY TO CHECK IF THIS IS A SPECIAL PREFIX IN A DIFFERENT ZONE (CQ OR ITU)
-        if (prefs[n].contains('(')>0 ){ // The prefix contains special CQzone
-     cqzone = (prefs[n].section('(',1)).section(')',0,0).toInt();
-        }
+          finalPrefix = prefs[n];
 
-        if (prefs[n].contains('[')>0 ){ // The prefix contains special CQzone
-         ituzone = (prefs[n].section('[',1)).section(']',0,0).toInt();
-        }
- 
- if (prefs[n].contains('[') ){
-          finalPrefix = prefs[n].left(prefs[n].find('['));
-        }
-        if (prefs[n].contains('(') ){
-          finalPrefix = prefs[n].left(prefs[n].find('('));      
-        }
+          // Here I have the prefix but also the (zone)[zone] when special zone is added 
+          // HERE IS NECESARY TO CHECK IF THIS IS A SPECIAL PREFIX IN A DIFFERENT ZONE (CQ OR ITU)
+          if (finalPrefix.contains("(")>0 ){ // The prefix contains special CQzone
+           cqzone = (finalPrefix.section("(",1)).section(")",0,0).toInt();
+          }
 
+          if (finalPrefix.contains("[")>0 ){ // The prefix contains special CQzone
+           ituzone = (finalPrefix.section("[",1)).section("]",0,0).toInt();
+          }
+          if (finalPrefix.contains("[") >0 ){
+           finalPrefix = finalPrefix.left((finalPrefix).find("["));
+          }
 
-	World::cqMap[finalPrefix] = cqzone;
-	World::ituMap[finalPrefix] = ituzone;
-	World::map[finalPrefix] = entity;
-//	World::cqMapi[cqzone] = number;
-//	World::ituMapi[ituzone] = number;
-          //entity.addPrefix(prefs[n].latin1());
+          if (prefs[n].contains("(") >0 ){
+           finalPrefix = finalPrefix.left(finalPrefix.find("("));
+          }
+          if ((finalPrefix.contains("=")>0) ){
+           finalPrefix = finalPrefix.remove("=");
+          }
+
+	  //entity.addPrefix(finalPrefix);
+          World::cqMap[finalPrefix] = cqzone;
+          World::ituMap[finalPrefix] = ituzone;
+
+          World::map[finalPrefix] = entity;
           n++;
-        }//
+        }
+
         datab = stream.readLine();
-        datab.remove(0,4);  //removing the spaces at the begining of the lines
-        prefs = QStringList::split(SEPARATOR2, datab );
-      }// Now we will process when there is ";"
-      ij = (datab.contains(','));
-      n = 0;
-      while (n <= ij){  // Maybe it is only <, not <=
-        if (prefs[n].contains(';')){
-          j = prefs[n].length() - 1;
-          prefs[n].truncate(j);
-//          entity.addPrefix(prefs[n].latin1());
-        }else{
-        }
- finalPrefix = prefs[n];
- 
- // Is a prefix with a Zone?
- 
- 
- // HERE IS NECESARY TO CHECK IF THIS IS A SPECIAL PREFIX IN A DIFFERENT ZONE (CQ OR ITU)
-        if (prefs[n].contains('(')>0 ){ // The prefix contains special CQzone
-     cqzone = (prefs[n].section('(',1)).section(')',0,0).toInt();
-        }
+        datab.stripWhiteSpace();  //removing the spaces at the begining of the lines
+   //     prefs = QStringList::split(SEPARATOR2, datab );
 
-        if (prefs[n].contains('[')>0 ){ // The prefix contains special CQzone
-         ituzone = (prefs[n].section('[',1)).section(']',0,0).toInt();
-        }
- if (prefs[n].contains('[') ){
-          finalPrefix = prefs[n].left(prefs[n].find('['));
-        }
-        if (prefs[n].contains('(') ){
-          finalPrefix = prefs[n].left(prefs[n].find('('));      
-        }
+      }
+      // Now we will process when there is ";", the last line of prefixes in an Entity
+//cout << "DATAB con ; #" << datab << "#" << endl;
+	datab.stripWhiteSpace();
+	datab.remove(0,4);
 
- World::cqMap[finalPrefix] = cqzone;
- World::ituMap[finalPrefix] = ituzone;    
+      prefs = QStringList::split(SEPARATOR2, datab );
+      ij = (datab.contains(","));
+      if (ij==0){
+	finalPrefix = datab;
+        if ((finalPrefix.contains("=")>0) ){
+         finalPrefix = finalPrefix.remove("=");
+        }
+        if ((datab.contains(";")>0) ){
+         finalPrefix = finalPrefix.remove(";");
+        }
         World::map[finalPrefix] = entity;
 
+      }else{
+      n = 0;
+      while (n <= ij){
+        cqzone = fields[1].toInt();
+        ituzone = fields[2].toInt();
+        finalPrefix = prefs[n];
+ 	if ((finalPrefix.contains(";")>0) ){
+         finalPrefix = finalPrefix.remove(";");
+        }
+
+
+        // Here I have the prefix but also the (zone)[zone] when special zone is added 
+        // HERE IS NECESARY TO CHECK IF THIS IS A SPECIAL PREFIX IN A DIFFERENT ZONE (CQ OR ITU)
+        if (finalPrefix.contains("(")>0 ){ // The prefix contains special CQzone
+         cqzone = (finalPrefix.section("(",1)).section(")",0,0).toInt();
+        }
+
+        if (finalPrefix.contains("[")>0 ){ // The prefix contains special CQzone
+         ituzone = (finalPrefix.section("[",1)).section("]",0,0).toInt();
+        }
+        if (finalPrefix.contains("[") >0 ){
+         finalPrefix = finalPrefix.left((finalPrefix).find("["));
+        }
+
+        if (finalPrefix.contains("(") >0 ){
+         finalPrefix = finalPrefix.left(finalPrefix.find("("));
+        }
+        if ((finalPrefix.contains("=")>0) ){
+         finalPrefix = finalPrefix.remove("=");
+        }
+        if ((finalPrefix.contains(";")>0) ){
+         finalPrefix = finalPrefix.remove(";");
+        }
+	//entity.addPrefix(finalPrefix);
+        World::cqMap[finalPrefix] = cqzone;
+        World::ituMap[finalPrefix] = ituzone;
+
+        World::map[finalPrefix] = entity;
         n++;
       }
+      }
+
 
     }
   created = true;
@@ -176,11 +222,13 @@ void World::create(){
 
 }
 
-QString World::getPrefix() const{
-    return prefix;
+QString World::getPrefix(const QString tqrz){
+	aux = findEntity(tqrz);
+	return prefix;
 }
 
 
+
 // We obtain the Entity from a call
 // It receives a string, get the prefix and send it to
 //   bool Entity::findPrefix(const QString tprx)
@@ -193,55 +241,54 @@ int World::findEntity(const QString string){
 
 // The first task is to isolate the prefix
 
-	prefixa = string;
-	prefixab = string;
-	prefix = "NULL";
-	qrz = prefixa;      // For last checks
-	qrz2 = qrz;
-	i = 0;
+  prefixa = string;
+  prefixab = string;
+  prefix = "NULL";
+  qrz = prefixa;      // For last checks
+  qrz2 = qrz;
+  i = 0;
 
-	if(( (prefixa.contains('/')) || (prefixa.contains('\\')) )){
-		i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
-		if (i!=0){
-			//   prefix = prefixa;
-			return i;
-		}
-		if (prefixa.endsWith("/")||prefixa.endsWith("\\")){ // We look for calls ending in slash "/" or "\"
-			
-			prefixa.remove(prefixa.length()-1,1);
-		}
-		if (prefixa.contains('/')){
-			ij = prefixa.find('/');
-			if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
-				prefixab = prefixa.left(ij);
-				qrz2 = prefixab;
-			}else{// Like in EA4TV/F
-				if (!((prefixa.upper()).endsWith("/P"))	// Portable
-				&& (!(prefixa.upper()).endsWith("/B"))	// Beacon
-				&& !((prefixa.upper()).endsWith("/M"))	//Mobile
-				&& !((prefixa.upper()).endsWith("/MM"))  // Maritime mobile
-				&& !((prefixa.upper()).endsWith("/J"))  // JOTA Scout
-				&& (!(prefixa.upper()).endsWith("/QRP"))
-				&& (!(prefixa.upper()).endsWith("/0"))
-				&& (!(prefixa.upper()).endsWith("/1"))
-				&& (!(prefixa.upper()).endsWith("/2"))
-				&& (!(prefixa.upper()).endsWith("/3"))
-				&& (!(prefixa.upper()).endsWith("/4"))
-				&& (!(prefixa.upper()).endsWith("/5"))
-				&& (!(prefixa.upper()).endsWith("/6"))
-				&& (!(prefixa.upper()).endsWith("/7"))
-				&& (!(prefixa.upper()).endsWith("/8"))
-				&& (!(prefixa.upper()).endsWith("/9"))){
-			// It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
-			// So let's go  
-					if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
-					// This is Conway Reef
-						prefixa = "3D2AM";
-						return giveEnt(prefixa);
-					}
-					if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
-					// This is Rotuma
-						prefixa = "3D2AA";
+  if(( (prefixa.contains('/')) || (prefixa.contains('\\')) )){
+    i = giveEnt(prefixa); // Checking full "special prefixes" like "4U/OH2BBF" first
+    if (i!=0){
+      return i;
+    }
+    if (prefixa.endsWith("/")||prefixa.endsWith("\\")){ // We look for calls ending in slash "/" or "\"
+      prefixa.remove(prefixa.length()-1,1);
+    }
+    if (prefixa.contains('/')){
+      ij = prefixa.find('/');
+      if ( (abs)(ij) < (abs)((prefixa.length())- ij)  ) { //Like in F/EA4TV
+        prefixab = prefixa.left(ij);
+        qrz2 = prefixab;
+      }else{ // Like in EA4TV/F
+        if (!((prefixa.upper()).endsWith("/P"))	// Portable
+        && !((prefixa.upper()).endsWith("/MM"))  // Maritime mobile
+        && (!(prefixa.upper()).endsWith("/B"))	// Beacon
+        && !((prefixa.upper()).endsWith("/M"))	//Mobile
+        && !((prefixa.upper()).endsWith("/J"))  // JOTA Scout
+        && (!(prefixa.upper()).endsWith("/LH")) // Light House
+        && (!(prefixa.upper()).endsWith("/QRP"))
+        && (!(prefixa.upper()).endsWith("/0"))
+        && (!(prefixa.upper()).endsWith("/1"))
+        && (!(prefixa.upper()).endsWith("/2"))
+        && (!(prefixa.upper()).endsWith("/3"))
+        && (!(prefixa.upper()).endsWith("/4"))
+        && (!(prefixa.upper()).endsWith("/5"))
+        && (!(prefixa.upper()).endsWith("/6"))
+        && (!(prefixa.upper()).endsWith("/7"))
+        && (!(prefixa.upper()).endsWith("/8"))
+        && (!(prefixa.upper()).endsWith("/9"))) {
+	// It is necessary to check for special prefixes like /r = Rotuma or /a = Mount Athos...
+	// So let's go
+          if ( (prefixa.upper().endsWith("/C")) && (prefixa.upper().startsWith("3D2" )) ){
+          // This is Conway Reef
+            prefixa = "3D2AM";
+            return giveEnt(prefixa);
+          }
+         if ( (prefixa.upper().endsWith("/R")) && (prefixa.upper().startsWith("3D2" )) ){
+         // This is Rotuma
+	prefixa = "3D2AA";
 						return giveEnt(prefixa);
 					}
 					if ( (prefixa.upper().endsWith("/B")) && (prefixa.upper().startsWith("3Y" )) ){
@@ -344,9 +391,11 @@ int World::findEntity(const QString string){
 						prefixa = "ZK1AAH";
 						return giveEnt(prefixa);
 					}
-            				prefixab = prefixa.right(prefixa.length()-(ij+1));
+					//TODO Check this prefixab = prefixa;
+            				prefixab = prefixa; prefixa.right(prefixa.length()-(ij+1));
 				}else{  // It is a EA4TV/P or EA4TV/QRP    
 					// Peter I, is a special "/P" station... so we need to check it.
+
 					if ( (prefixa.upper().endsWith("/P")) && (prefixa.upper().startsWith("3Y" )) ){
 						// This is Peter I
 						prefixa = "3Y0PI";
@@ -360,13 +409,14 @@ int World::findEntity(const QString string){
 					}
 					prefixab =  prefixa.left(ij);
 					if ((prefixa.upper().endsWith("/M"))||(prefixa.upper().endsWith("/MM"))){// /M and /MM does not count as DXCC
-						return -1;
+						return 0;
 					}else{// Normal /p, /m, ... prefix
-
+// 			cout << "world::findEntity: Its a special Call-2: " << prefixa << endl;
 					}
 				}
 			qrz2 = prefixab;
-      }
+	}
+	
     }else{
       ij = prefixa.find("\\");
       if ( (abs)(ij) < (abs)(prefixa.length()-ij ) ) { //Like in F\EA4TV
@@ -453,7 +503,6 @@ int World::findEntity(const QString string){
       return i;
   }
 
-
   // We have to check for calls as 3XY1L when reading from a file
   // but just if we have not find another Entity
   if (i == 0){
@@ -468,7 +517,7 @@ int World::findEntity(const QString string){
     prefixa.truncate(2);
     i = giveEnt(prefixa);
 }
-}  
+}
   return i; // "i" is the Entity number
 }
 
@@ -482,7 +531,7 @@ Entity World::getEntByNumb(int num){
 ************************************************************
 */
 // Maybe the way to proceed is to check without running all the list!  
-  
+
   itN = nmap.begin();
   itN = nmap.find(i);
   if (itN != nmap.end()){
@@ -491,17 +540,6 @@ Entity World::getEntByNumb(int num){
       itN = nmap.begin();
   }
   return (itN.data());
-
-/*
- // found = false;
-   for ( it = map.begin(); it != map.end(); ++it ) {
-    if ( (it.data().getNumb()) == i){
-        return (it.data());
-    }
-   }
-    it = map.end();
-    return (it.data());
-*/
 }
 
 
@@ -511,6 +549,7 @@ int World::giveEnt(const QString tqrz){
   it = map.find(qrz);
   if (map.find(qrz) != map.end()){
       prefix = qrz;
+//cout << "giveEnt: " << qrz << QString::number(it.data().getNumb()) << endl;
       return it.data().getNumb();
   }
   else
@@ -578,16 +617,45 @@ int World::getCqz(){
 }
 
 int World::getCqzFromCall(const QString  tqrz){
+//TODO: Check if the i=... is needed and check if this function is needed or just an unefficiency
 	i = findEntity(tqrz);
 	return getCqz();
 }
 
+int World::getITUzFromCall(const QString  tqrz){
+//TODO: Check if the i=... is needed and check if this function is needed or just an unefficiency
+	i = findEntity(tqrz);
+	return getItuz();
+}
+
+int World::getCQzFromEntity(const int tint){ // Uses getCqz
+	i = tint;
+	return getCqz();
+
+}
+
+int World::getITUzFromEntity(const int tint){ // Uses getCqz
+	i = tint;
+	return getItuz();
+
+}
+
 int World::howManyEntities(){
-  it = map.end();
-  return it.data().getNumb();
+	return number;
+  //it = map.end();
+  //return it.data().getNumb();
 }
 
 bool World::isWorldCreated(){
     return created;
 }
 
+QString World::getEntityName(int num){
+	return "NULL";
+}
+
+QString World::getMainPrefix (int num){
+
+	return "NULL";
+}
+
