@@ -24,16 +24,15 @@
  *****************************************************************************/
 #ifndef WORLD_H
 #define WORLD_H
+#ifndef HAVE_CONFIG_H
+#include <config.h>
+#endif
 const char SEPARATOR1 = ':';
 const char SEPARATOR2 = ',';
-//#include <qwidget.h>
+#include <stdlib.h>
 #include <qstring.h>
-#include <qvaluelist.h>
-#include <klistview.h>
 #include <qstringlist.h>
 #include <qfile.h>
-//#include <qmessagebox.h>
-//#include <qfiledialog.h>
 #include <qmap.h>
 #include <qdir.h>
 #include "entity.h"
@@ -46,7 +45,6 @@ class World{
 public:
 
 	World();
-
 	~World();
 
 	void create();
@@ -55,25 +53,22 @@ public:
 	int findEntity(const QString  string);	// If no Entity is found, we return "0"
 
   // HACK: I should fool-proof this function adding a QString as a call to get the zone
-	QString getPrefix() const; // Returns the prefix we found in findEntity.
+	QString getPrefix(const QString tqrz); // Returns the prefix we found in findEntity.
 
-//  int getEnti(const QString ttqrz);
-//  int getEntiCompleteQRZ(const QString ttqrz);
-//  Entity getEnt(const QString ttqrz);
 	Entity getEntByNumb(int num);
-//  int getAdifNumber(const QString entity);
 	int giveEnt(const QString tqrz);
 	int howManyEntities();
 
 	bool isSpecial(const QString &tpfx);  // This functions returns true if Entity has special zones
                                         // per prefixes i.e. BY, UA, ...
-	int getItuz(); // HACK: I should fool-proof this function adding a QString as a call to get the zone
-	int getCqz();  // HACK: I should fool-proof this function adding a QString as a call to get the zone
-	//int getItuz(int tenti);
-	//int getCqz(int tenti);
 	int getCqzFromCall(const QString  tqrz); // Uses findEntity and getCqz
-// isSpecial,  maybe is to be deleted.
-  
+	int getITUzFromCall(const QString  tqrz); // Uses findEntity and getCqz
+	int getCQzFromEntity(const int tint); // Uses getCqz
+	int getITUzFromEntity(const int tint); // Uses getCqz
+
+	QString getEntityName(int num);
+	QString getMainPrefix (int num);
+
 private:
   int number;
 //  bool found;
@@ -86,7 +81,8 @@ private:
   Entity entity;
   QString prefixa;
   QString prefixab;
-  QString klogDir;  
+  QString klogDir;
+
 //  int location[0,0];
 
 	typedef QMap<QString, Entity> EntityMap;  // To map Prefix/Entity
@@ -94,7 +90,7 @@ private:
 	typedef QMap<QString, int> EntityZMap;    // To map Prefix/Zone (CQ/ITU for all)
 //	typedef QMap<int, int> EntityIIMap;	// To map Zone/Entity(number)
 
-	EntityMap map; 				// Prefix/Entity
+	EntityMap map;				// Prefix/Entity
 	EntityMap::Iterator it;
 	EntityNMap nmap;			// EntityNumber/Entity
 	EntityNMap::Iterator itN;		 
@@ -102,6 +98,9 @@ private:
 	EntityZMap::Iterator itCQ, itITU;
 //	EntityIIMap::cqMapi, ituMapi;			//TODO Map entity/zone to do things faster
 //	EntityIIMap::Iteraror itCqMapi, itItuMapi;	//TODO Map entity/zone to do things faster
+	int getItuz(); // HACK: I should fool-proof this function adding a QString as a call to get the zone
+	int getCqz();  // HACK: I should fool-proof this function adding a QString as a call to get the zone
+
 
 };
 #endif
